package #
Date::Manip::Offset::off088;
# Copyright (c) 2008-2025 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Sun Mar  2 17:20:12 EST 2025
#    Data version: tzdata2025a
#    Code version: tzcode2025a

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.97';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '+04:00:00';

%Offset        = (
   0 => [
      'indian/mauritius',
      'asia/dubai',
      'europe/astrakhan',
      'europe/samara',
      'europe/saratov',
      'europe/ulyanovsk',
      'asia/baku',
      'asia/tbilisi',
      'asia/yerevan',
      'etc/gmt+4',
      'q',
      'europe/volgograd',
      'europe/kirov',
      'europe/moscow',
      'europe/simferopol',
      'asia/aqtau',
      'asia/oral',
      'asia/atyrau',
      'asia/yekaterinburg',
      'asia/aqtobe',
      'asia/ashgabat',
      'asia/qostanay',
      'asia/tehran',
      'asia/qatar',
      'asia/kabul',
      'asia/qyzylorda',
      'asia/samarkand',
      ],
   1 => [
      'europe/moscow',
      'europe/saratov',
      'europe/volgograd',
      'europe/astrakhan',
      'europe/kirov',
      'europe/samara',
      'europe/ulyanovsk',
      'asia/baghdad',
      'asia/tbilisi',
      'europe/simferopol',
      'asia/yerevan',
      'asia/baku',
      'europe/chisinau',
      'europe/kyiv',
      'europe/minsk',
      'europe/kaliningrad',
      'europe/riga',
      'europe/tallinn',
      'europe/vilnius',
      'europe/istanbul',
      'asia/jerusalem',
      ],
);

1;
