#!/usr/bin/perl

use warnings;
use strict;
use Test::Inter;
$::ti = new Test::Inter $0;
require "tests.pl";

our $dmt = new Date::Manip::TZ;
our $obj = $dmt->base();
$dmt->config("forcedate","now,America/New_York");

sub test {
   my(@test) = @_;
   my @ret    = $obj->check(@test);
   return @ret;
}

my $tests="

[ a b c d e f ]         => 0

[ 1990 13 1 1 1 1 ]     => 0

[ 1990 7 3 0 0 0 ]      => 1

[ 1990 7 3 24 0 0 ]     => 1

[ 1990 7 3 24 30 0 ]    => 0

[ 1990 07 03 00 00 00 ] => 1

";

$::ti->tests(func  => \&test,
             tests => $tests);
$::ti->done_testing();

#Local Variables:
#mode: cperl
#indent-tabs-mode: nil
#cperl-indent-level: 3
#cperl-continued-statement-offset: 2
#cperl-continued-brace-offset: 0
#cperl-brace-offset: 0
#cperl-brace-imaginary-offset: 0
#cperl-label-offset: 0
#End:
